<?php

namespace Drupal\sticky_local_tasks\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Defines a form that configures forms module settings.
 */
class StickyLocalTasksForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'sticky_local_tasks_admin_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'sticky_local_tasks.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('sticky_local_tasks.settings');

    $form['options'] = [
      '#type' => 'details',
      '#title' => $this->t('Sticky Local Tasks Options'),
      '#open' => TRUE,
    ];

    $form['options']['default_local_tasks'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Preserve the default Drupal local tasks in place and add a duplicate sticky local tasks.'),
      '#default_value' => $config->get('default_local_tasks'),
    ];

    $form['options']['static_position'] = [
      '#type' => 'radios',
      '#title' => $this->t('Select your preferred sticky local tasks position'),
      '#options' => [
        'bottom-right' => $this->t('Bottom Right'),
        'bottom-left' => $this->t('Bottom Left'),
      ],
      '#required' => TRUE,
      '#default_value' => $config->get('static_position'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('sticky_local_tasks.settings')
      ->set('static_position', $form_state->getValue('static_position'))
      ->set('default_local_tasks', $form_state->getValue('default_local_tasks'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}